
#ifndef GAMMARAY_CLIENT_EXPORT_H
#define GAMMARAY_CLIENT_EXPORT_H

#ifdef GAMMARAY_CLIENT_STATIC_DEFINE
#  define GAMMARAY_CLIENT_EXPORT
#  define GAMMARAY_CLIENT_NO_EXPORT
#else
#  ifndef GAMMARAY_CLIENT_EXPORT
#    ifdef gammaray_client_EXPORTS
        /* We are building this library */
#      define GAMMARAY_CLIENT_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define GAMMARAY_CLIENT_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef GAMMARAY_CLIENT_NO_EXPORT
#    define GAMMARAY_CLIENT_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef GAMMARAY_CLIENT_DEPRECATED
#  define GAMMARAY_CLIENT_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef GAMMARAY_CLIENT_DEPRECATED_EXPORT
#  define GAMMARAY_CLIENT_DEPRECATED_EXPORT GAMMARAY_CLIENT_EXPORT GAMMARAY_CLIENT_DEPRECATED
#endif

#ifndef GAMMARAY_CLIENT_DEPRECATED_NO_EXPORT
#  define GAMMARAY_CLIENT_DEPRECATED_NO_EXPORT GAMMARAY_CLIENT_NO_EXPORT GAMMARAY_CLIENT_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef GAMMARAY_CLIENT_NO_DEPRECATED
#    define GAMMARAY_CLIENT_NO_DEPRECATED
#  endif
#endif

#endif /* GAMMARAY_CLIENT_EXPORT_H */
